"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var icss_utils_1 = require("icss-utils");
var postcss = require("postcss");
var postcssIcssSelectors = require("postcss-icss-selectors");
var classTransforms_1 = require("./classTransforms");
var processor = postcss(postcssIcssSelectors({ mode: 'local' }));
exports.getClasses = function (css) {
    return icss_utils_1.extractICSS(processor.process(css).root).icssExports;
};
var classNameToProperty = function (className) { return "'" + className + "': string;"; };
var flattenClassNames = function (previousValue, currentValue) {
    if (previousValue === void 0) { previousValue = []; }
    return previousValue.concat(currentValue);
};
var classnamesTypes = "\ndeclare type ClassKeys = typeof classes;\n\ndeclare type ClassDictionary = { [id in keyof ClassKeys]: any };\n\ndeclare type ClassValue = ClassKeys | ClassDictionary;\n\ndeclare interface ClassArray extends Array<ClassValue> {}\n\ndeclare const classNamesFn: (...classes: ClassValue[]) => string;\n\nexport default classNamesFn";
exports.createExports = function (classes, options) { return "declare const classes: {\n  " + Object.keys(classes)
    .map(classTransforms_1.transformClasses(options.camelCase))
    .reduce(flattenClassNames)
    .map(classNameToProperty)
    .join('\n  ') + "\n};\n\n" + (options.classnamesLoader ? classnamesTypes : 'export default classes') + ";\n"; };
exports.getDtsSnapshot = function (ts, scriptSnapshot, options) {
    var css = scriptSnapshot.getText(0, scriptSnapshot.getLength());
    var classes = exports.getClasses(css);
    var dts = exports.createExports(classes, options);
    return ts.ScriptSnapshot.fromString(dts);
};
